Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(415)

Unified Diff: chrome/browser/sync/glue/theme_util.cc

Issue 5730004: Rename ExtensionsService to ExtensionService. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix typo Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/theme_util.cc
diff --git a/chrome/browser/sync/glue/theme_util.cc b/chrome/browser/sync/glue/theme_util.cc
index 9e94632696056423c7130452250b7615251ae05e..a0a5da25e63bcb7938bea0c158c3a2309a5acbe8 100644
--- a/chrome/browser/sync/glue/theme_util.cc
+++ b/chrome/browser/sync/glue/theme_util.cc
@@ -10,7 +10,7 @@
#include "base/scoped_ptr.h"
#include "chrome/browser/extensions/extension_install_ui.h"
#include "chrome/browser/extensions/extension_updater.h"
-#include "chrome/browser/extensions/extensions_service.h"
+#include "chrome/browser/extensions/extension_service.h"
#if defined(TOOLKIT_USES_GTK)
#include "chrome/browser/gtk/gtk_theme_provider.h"
#endif
@@ -85,7 +85,7 @@ void SetCurrentThemeFromThemeSpecifics(
std::string id(theme_specifics.custom_theme_id());
GURL update_url(theme_specifics.custom_theme_update_url());
VLOG(1) << "Applying theme " << id << " with update_url " << update_url;
- ExtensionsService* extensions_service = profile->GetExtensionsService();
+ ExtensionService* extensions_service = profile->GetExtensionService();
CHECK(extensions_service);
const Extension* extension = extensions_service->GetExtensionById(id, true);
if (extension) {
@@ -138,7 +138,7 @@ void SetCurrentThemeFromThemeSpecifics(
kInstallSilently, kEnableOnInstall, kEnableIncognitoOnInstall);
ExtensionUpdater* extension_updater = extensions_service->updater();
// Auto-updates should now be on always (see the construction of
// the ExtensionsService in ProfileImpl::InitExtensions()).
if (!extension_updater) {
LOG(DFATAL) << "Extension updater unexpectedly NULL; "
<< "auto-updates may be turned off";
@@ -138,7 +138,7 @@ void SetCurrentThemeFromThemeSpecifics(
ExtensionUpdater* extension_updater = extensions_service->updater();
// Auto-updates should now be on always (see the construction of
- // the ExtensionsService in ProfileImpl::InitExtensions()).
+ // the ExtensionService in ProfileImpl::InitExtensions()).
if (!extension_updater) {
LOG(DFATAL) << "Extension updater unexpectedly NULL; "
« no previous file with comments | « chrome/browser/sync/glue/extension_util_unittest.cc ('k') | chrome/browser/sync/glue/theme_util_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698